@@ -73,7 +73,7 @@ class LkeClient(AbstractClient):
 
 
     def CreateApp(self, request):
-        """创建只是引擎应用，包括：知识管理应用、知识摘要应用、标签提取应用。
+        """创建知识引擎应用。
 
         :param request: Request instance for CreateApp.
         :type request: :class:`tencentcloud.lke.v20231130.models.CreateAppRequest`
@@ -187,6 +187,32 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateReconstructDocumentFlow(self, request):
+        """本接口为异步接口的发起请求接口，用于发起文档解析任务。
+        文档解析支持将图片或PDF文件转换成Markdown格式文件，可解析包括表格、公式、图片、标题、段落、页眉、页脚等内容元素，并将内容智能转换成阅读顺序。
+
+        体验期间单账号限制qps仅为1，若有正式接入需要请与产研团队沟通开放。
+
+        :param request: Request instance for CreateReconstructDocumentFlow.
+        :type request: :class:`tencentcloud.lke.v20231130.models.CreateReconstructDocumentFlowRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.CreateReconstructDocumentFlowResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateReconstructDocumentFlow", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateReconstructDocumentFlowResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateRejectedQuestion(self, request):
         """创建拒答问题
 
@@ -280,7 +306,7 @@ class LkeClient(AbstractClient):
 
 
     def DeleteDoc(self, request):
-        """创建企业
+        """删除文档
 
         :param request: Request instance for DeleteDoc.
         :type request: :class:`tencentcloud.lke.v20231130.models.DeleteDocRequest`
@@ -556,7 +582,7 @@ class LkeClient(AbstractClient):
 
 
     def DescribeRobotBizIDByAppKey(self, request):
-        """通过appKey获取机器人业务ID
+        """通过appKey获取应用业务ID
 
         :param request: Request instance for DescribeRobotBizIDByAppKey.
         :type request: :class:`tencentcloud.lke.v20231130.models.DescribeRobotBizIDByAppKeyRequest`
@@ -786,8 +812,8 @@ class LkeClient(AbstractClient):
 
 
     def GetEmbedding(self, request):
-        """获取特征向量
-        本接口有单账号调用上限控制，如您有提高并发限制的需求请 [联系我们](https://cloud.tencent.com/act/event/Online_service) 。
+        """本接口（GetEmbedding）调用文本表示模型，将文本转化为用数值表示的向量形式，可用于文本检索、信息推荐、知识挖掘等场景。
+        本接口（GetEmbedding）有单账号调用上限控制，如您有提高并发限制的需求请 [联系我们](https://cloud.tencent.com/act/event/Online_service) 。
 
         :param request: Request instance for GetEmbedding.
         :type request: :class:`tencentcloud.lke.v20231130.models.GetEmbeddingRequest`
@@ -832,6 +858,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def GetReconstructDocumentResult(self, request):
+        """本接口为异步接口的查询结果接口，用于获取文档解析处理结果。
+
+        :param request: Request instance for GetReconstructDocumentResult.
+        :type request: :class:`tencentcloud.lke.v20231130.models.GetReconstructDocumentResultRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.GetReconstructDocumentResultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetReconstructDocumentResult", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetReconstructDocumentResultResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def GetTaskStatus(self, request):
         """获取任务状态
 
@@ -1477,7 +1526,8 @@ class LkeClient(AbstractClient):
 
 
     def ParseDoc(self, request):
-        """解析拆分文档。该接口需开通文档解析原子能力后调用。文档解析原子能力内测中，如有需要请联系架构师或 [联系客服](https://cloud.tencent.com/act/event/Online_service)  。
+        """接口即将下线，请切换使用新接口：[文档解析](https://cloud.tencent.com/document/product/1759/107504)
+        解析拆分文档。该接口需开通文档解析原子能力后调用。文档解析原子能力内测中，如有需要请联系架构师或 [联系客服](https://cloud.tencent.com/act/event/Online_service)  。
 
         :param request: Request instance for ParseDoc.
         :type request: :class:`tencentcloud.lke.v20231130.models.ParseDocRequest`
@@ -1523,8 +1573,8 @@ class LkeClient(AbstractClient):
 
 
     def QueryRewrite(self, request):
-        """多轮改写
-        本接口有单账号调用上限控制，如您有提高并发限制的需求请 [联系我们](https://cloud.tencent.com/act/event/Online_service) 。
+        """多轮改写（QueryRewrite）主要用于多轮对话中，进行指代消解和省略补全。使用本接口，无需输入prompt描述，根据对话历史即可生成更精确的用户查询。在应用场景上，本接口可应用于智能问答、对话式搜索等多种场景。
+        本接口（QueryRewrite）有单账号调用上限控制，如您有提高并发限制的需求请 [联系我们](https://cloud.tencent.com/act/event/Online_service) 。
 
         :param request: Request instance for QueryRewrite.
         :type request: :class:`tencentcloud.lke.v20231130.models.QueryRewriteRequest`
@@ -1569,6 +1619,31 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ReconstructDocument(self, request):
+        """支持将图片或PDF文件转换成Markdown格式文件，可解析包括表格、公式、图片、标题、段落、页眉、页脚等内容元素，并将内容智能转换成阅读顺序。
+
+        体验期间单账号限制qps仅为1，若有正式接入需要请与产研团队沟通开放。
+
+        :param request: Request instance for ReconstructDocument.
+        :type request: :class:`tencentcloud.lke.v20231130.models.ReconstructDocumentRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.ReconstructDocumentResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ReconstructDocument", params, headers=headers)
+            response = json.loads(body)
+            model = models.ReconstructDocumentResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ResetSession(self, request):
         """重置会话
 
